@@ -18,10 +18,10 @@
 #' value or a vector of elements. The input type should be character, but the function will
 #' comply with integers so long as they are all present in the \code{ID} column of the data.
 #'
-#' @param bp_type Optional argument. Determines whether to calculate ARV for SBP
-#' values or DBP values. Default is 0 corresponding to output for both SBP & DBP.
-#' For \strong{both} SBP and DBP ARV values use bp_type = 0, for \strong{SBP-only}
-#' use bp_type = 1, and for \strong{DBP-only} use bp_type = 2
+#' @param bp_type Optional argument. Determines whether to calculate CV for SBP
+#' values or DBP values, or both. For \strong{both SBP and DBP} ARV values use bp_type = 'both',
+#' for \strong{SBP-only} use bp_type = 'sbp, and for \strong{DBP-only} use bp_type = 'dbp'.
+#' If no type specified, default will be set to 'both'
 #'
 #' @param add_groups Optional argument. Allows the user to aggregate the data by an
 #' additional "group" to further refine the output. The supplied input must be a
@@ -64,17 +64,21 @@
 #' data(bp_jhs)
 #'
 #' # Process bp_hypnos
-#' hypnos_proc <- process_data(bp_hypnos, sbp = "SYST", dbp = "DIAST", date_time = "date.time",
+#' hyp_proc <- process_data(bp_hypnos, sbp = "SYST", dbp = "DIAST", date_time = "date.time",
 #' id = "id", wake = "wake", visit = "visit", hr = "hr", pp ="pp", map = "map", rpp = "rpp")
 #' # Process bp_jhs data
 #' jhs_proc <- process_data(bp_jhs, sbp = "Sys.mmHg.", dbp = "Dias.mmHg.", date_time = "DateTime",
 #' hr = "Pulse.bpm.")
 #'
 #' # CV Calculation
-#' bp_cv(hypnos_proc, inc_date = TRUE, add_groups = "SBP_Category")
+#' bp_cv(hyp_proc, inc_date = TRUE, add_groups = "SBP_Category", bp_type = 'sbp')
 #' bp_cv(jhs_proc, add_groups = c("meal_time"))
 #' # Notice that meal_time is not a column from process_data, but it still works
-bp_cv <- function(data, inc_date = FALSE, subj = NULL, bp_type = 0, add_groups = NULL, inc_wake = TRUE){
+bp_cv <- function(data, inc_date = FALSE, subj = NULL, bp_type = c('both', 'sbp', 'dbp'), add_groups = NULL, inc_wake = TRUE){
+
+  # Match argument for bp_type
+  bp_type <- tolower(bp_type)
+  bp_type <- match.arg(bp_type)
 
   SBP = DBP = ID = . = NULL
   rm(list = c('SBP', 'DBP', 'ID', '.'))
@@ -97,7 +101,8 @@ bp_cv <- function(data, inc_date = FALSE, subj = NULL, bp_type = 0, add_groups =
   }
 
 
-  if(bp_type == 0){
+  # SBP and DBP
+  if(bp_type == 'both'){
 
     if(nrow(data) != length(which(!is.na(data$SBP) & !is.na(data$DBP))) ){
 
@@ -105,8 +110,8 @@ bp_cv <- function(data, inc_date = FALSE, subj = NULL, bp_type = 0, add_groups =
       data <- data[which(!is.na(data$SBP) & !is.na(data$DBP)),]
       #data <- data %>% dplyr::filter( complete.cases(SBP, DBP) )
     }
-
-  }else if(bp_type == 1){
+  # SBP Only
+  }else if(bp_type == 'sbp'){
 
     # SBP
     # check for missing values
@@ -114,7 +119,8 @@ bp_cv <- function(data, inc_date = FALSE, subj = NULL, bp_type = 0, add_groups =
       warning('Missing SBP values found in data set. Removing for calculation.')
       data <- data[which(!is.na(data$SBP)),]
     }
-  }else if(bp_type == 2){
+  # DBP Only
+  }else if(bp_type == 'dbp'){
 
     # DBP
     # check for missing values
@@ -144,9 +150,9 @@ bp_cv <- function(data, inc_date = FALSE, subj = NULL, bp_type = 0, add_groups =
     dplyr::group_by_at( dplyr::vars(grps) ) %>%
 
     # CV Calculation
-    { if (bp_type == 1) dplyr::summarise(., CV = sd(SBP, na.rm = TRUE) / mean(SBP, na.rm = TRUE) * 100, SD = sd(SBP),N = dplyr::n()) else . } %>% # SBP only
-    { if (bp_type == 2) dplyr::summarise(., CV = sd(DBP, na.rm = TRUE) / mean(DBP, na.rm = TRUE) * 100, SD = sd(DBP),N = dplyr::n()) else . } %>% # DBP only
-    { if (bp_type == 0) dplyr::summarise(., CV_SBP = sd(SBP, na.rm = TRUE) / mean(SBP, na.rm = TRUE) * 100,
+    { if (bp_type == 'sbp') dplyr::summarise(., CV = sd(SBP, na.rm = TRUE) / mean(SBP, na.rm = TRUE) * 100, SD = sd(SBP),N = dplyr::n()) else . } %>% # SBP only
+    { if (bp_type == 'dbp') dplyr::summarise(., CV = sd(DBP, na.rm = TRUE) / mean(DBP, na.rm = TRUE) * 100, SD = sd(DBP),N = dplyr::n()) else . } %>% # DBP only
+    { if (bp_type == 'both') dplyr::summarise(., CV_SBP = sd(SBP, na.rm = TRUE) / mean(SBP, na.rm = TRUE) * 100,
                                             CV_DBP = sd(DBP, na.rm = TRUE) / mean(DBP, na.rm = TRUE) * 100,
                                             SD_SBP = sd(SBP),
                                             SD_DBP = sd(DBP),
