@@ -27,10 +27,10 @@
 #' value or a vector of elements. The input type should be character, but the function will
 #' comply with integers so long as they are all present in the \code{ID} column of the data.
 #'
-#' @param bp_type Optional argument. Determines whether to calculate ARV for SBP
-#' values or DBP values. Default is 0 corresponding to output for both SBP & DBP.
-#' For \strong{both} SBP and DBP ARV values use bp_type = 0, for \strong{SBP-only}
-#' use bp_type = 1, and for \strong{DBP-only} use bp_type = 2
+#' @param bp_type Optional argument. Determines whether to calculate SV for SBP
+#' values or DBP values, or both. For \strong{both SBP and DBP} ARV values use bp_type = 'both',
+#' for \strong{SBP-only} use bp_type = 'sbp, and for \strong{DBP-only} use bp_type = 'dbp'.
+#' If no type specified, default will be set to 'both'
 #'
 #' @param add_groups Optional argument. Allows the user to aggregate the data by an
 #' additional "group" to further refine the output. The supplied input must be a
@@ -82,7 +82,11 @@
 #' bp_sv(hypnos_proc)
 #' bp_sv(jhs_proc, add_groups = c("meal_time"))
 #' # Notice that meal_time is not a column from process_data, but it still works
-bp_sv <- function(data, inc_date = FALSE, subj = NULL, bp_type = 0, add_groups = NULL, inc_wake = TRUE){
+bp_sv <- function(data, inc_date = FALSE, subj = NULL, bp_type = c('both', 'sbp', 'dbp'), add_groups = NULL, inc_wake = TRUE){
+
+  # Match argument for bp_type
+  bp_type <- tolower(bp_type)
+  bp_type <- match.arg(bp_type)
 
   SBP = DBP = ID = . = NULL
   rm(list = c('SBP', 'DBP', 'ID', '.'))
@@ -106,8 +110,8 @@ bp_sv <- function(data, inc_date = FALSE, subj = NULL, bp_type = 0, add_groups =
 
 
 
-  # Check for missing values
-  if(bp_type == 0){
+  # Check for missing values for both SBP and DBP
+  if(bp_type == 'both'){
 
     if(nrow(data) != length(which(!is.na(data$SBP) & !is.na(data$DBP))) ){
 
@@ -116,7 +120,8 @@ bp_sv <- function(data, inc_date = FALSE, subj = NULL, bp_type = 0, add_groups =
       #data <- data %>% dplyr::filter( complete.cases(SBP, DBP) )
     }
 
-  }else if(bp_type == 1){
+  # SBP Only
+  }else if(bp_type == 'sbp'){
 
     # SBP
     # check for missing values
@@ -124,7 +129,9 @@ bp_sv <- function(data, inc_date = FALSE, subj = NULL, bp_type = 0, add_groups =
       warning('Missing SBP values found in data set. Removing for calculation.')
       data <- data[which(!is.na(data$SBP)),]
     }
-  }else if(bp_type == 2){
+
+  # DBP Only
+  }else if(bp_type == 'dbp'){
 
     # DBP
     # check for missing values
@@ -155,9 +162,9 @@ bp_sv <- function(data, inc_date = FALSE, subj = NULL, bp_type = 0, add_groups =
     dplyr::group_by_at( dplyr::vars(grps) ) %>%
 
     # SV Calculation
-    { if (bp_type == 1) dplyr::summarise(., SV = sqrt( sum(( (SBP - dplyr::lag(SBP))[2:length(SBP - dplyr::lag(SBP))] )^2 ) / (dplyr::n() - 1)), N = dplyr::n()) else . } %>% # SBP only
-    { if (bp_type == 2) dplyr::summarise(., SV = sqrt( sum(( (DBP - dplyr::lag(DBP))[2:length(DBP - dplyr::lag(DBP))] )^2 ) / (dplyr::n() - 1)), N = dplyr::n()) else . } %>% # DBP only
-    { if (bp_type == 0) dplyr::summarise(., SV_SBP = sqrt( sum(( (SBP - dplyr::lag(SBP))[2:length(SBP - dplyr::lag(SBP))] )^2 ) / (dplyr::n() - 1)),
+    { if (bp_type == 'sbp') dplyr::summarise(., SV = sqrt( sum(( (SBP - dplyr::lag(SBP))[2:length(SBP - dplyr::lag(SBP))] )^2 ) / (dplyr::n() - 1)), N = dplyr::n()) else . } %>% # SBP only
+    { if (bp_type == 'dbp') dplyr::summarise(., SV = sqrt( sum(( (DBP - dplyr::lag(DBP))[2:length(DBP - dplyr::lag(DBP))] )^2 ) / (dplyr::n() - 1)), N = dplyr::n()) else . } %>% # DBP only
+    { if (bp_type == 'both') dplyr::summarise(., SV_SBP = sqrt( sum(( (SBP - dplyr::lag(SBP))[2:length(SBP - dplyr::lag(SBP))] )^2 ) / (dplyr::n() - 1)),
                                             SV_DBP = sqrt( sum(( (DBP - dplyr::lag(DBP))[2:length(DBP - dplyr::lag(DBP))] )^2 ) / (dplyr::n() - 1)),
                                             N = dplyr::n()) else . } # both SBP and DBP
 
